@@ -92,4 +92,12 @@ if [ -n "${WP_DEFAULT_THEME:-}" ]; then
   wp theme activate "$WP_DEFAULT_THEME"
 fi
 
+if [ -n "${WP_LOCALE:-}" ]; then
+  echo "Setting locale: $WP_LOCALE"
+  wp language core install "$WP_LOCALE"
+  wp language theme install --all "$WP_LOCALE"
+  wp language plugin install --all "$WP_LOCALE"
+  wp site switch-language "$WP_LOCALE"
+fi
+
 echo "✅ WordPress Installation complete"
