@@ -1,5 +1,3 @@
-from __future__ import annotations
-
 from .base import Provider
 from .hugo import HugoProvider
 from .laravel import LaravelProvider
@@ -8,6 +6,8 @@ from .node_static import NodeStaticProvider
 from .wordpress import WordPressProvider
 from .php import PhpProvider
 from .python import PythonProvider
+from .jekyll import JekyllProvider
+from .go import GoProvider
 from .staticfile import StaticFileProvider
 
 
@@ -21,5 +21,7 @@ def providers() -> list[type[Provider]]:
         WordPressProvider,
         PhpProvider,
         NodeStaticProvider,
+        JekyllProvider,
+        GoProvider,
         StaticFileProvider,
     ]
