@@ -10,6 +10,7 @@ from typing import List, NamedTuple
 from dataclasses import dataclass
 
 import pytest
+import shlex
 import shutil
 import contextlib
 import aiohttp
@@ -47,6 +48,12 @@ class E2ECase(NamedTuple):
 @pytest.mark.parametrize(
     "case",
     [
+        # Simple PHP site that calls phpinfo()
+        E2ECase(
+            path="examples/cdn",
+            serve_pattern=r"server is listening on",
+            http=[HTTPRequest(path="/", body_match=r"My CDN")],
+        ),
         # Simple PHP site that calls phpinfo()
         E2ECase(
             path="examples/php-nobuild",
@@ -62,7 +69,6 @@ class E2ECase(NamedTuple):
                 r"PHP 8\.3\.[0-9]+ Development Server \(http://localhost:[\d]+\) started"
             ),
             http=[HTTPRequest(path="/", body_match=r"PHP Version 8\.3\.[0-9]+")],
-            use_random_port=False,
         ),
         # PHP API example with JSON at / and greeting endpoint
         E2ECase(
@@ -172,7 +178,7 @@ class E2ECase(NamedTuple):
         BuildMode.Local,
         BuildMode.Wasmer,
         BuildMode.WasmerAndDocker,
-    ]
+    ],
 )
 async def test_end_to_end(case: E2ECase, build_mode: BuildMode):
     # Skip if `uv` is not available in PATH
@@ -194,8 +200,10 @@ async def test_end_to_end(case: E2ECase, build_mode: BuildMode):
     ]
     if build_mode == BuildMode.Wasmer:
         cmd.append("--wasmer")
+        cmd.append("--wasmer-registry=wasmer.io")
     elif build_mode == BuildMode.WasmerAndDocker:
         cmd.append("--wasmer")
+        cmd.append("--wasmer-registry=wasmer.io")
         cmd.append("--docker")
     elif build_mode == BuildMode.Local:
         # The default
@@ -206,16 +214,15 @@ async def test_end_to_end(case: E2ECase, build_mode: BuildMode):
 
     # Start process in a new session/process group to simplify termination.
     start_new_session = os.name != "nt"
-    creationflags = (
-        subprocess.CREATE_NEW_PROCESS_GROUP if os.name == "nt" else 0
-    )
+    creationflags = subprocess.CREATE_NEW_PROCESS_GROUP if os.name == "nt" else 0
 
     env = os.environ.copy()
     if case.use_random_port:
         port = get_free_port()
-        env["PORT"] = str(port)
     else:
-        port = 8080 # This is the default port if not specified
+        port = 8080  # This is the default port if not specified
+
+    cmd.append(f"--serve-port={port}")
 
     proc = await asyncio.create_subprocess_exec(
         *cmd,
@@ -234,7 +241,7 @@ async def test_end_to_end(case: E2ECase, build_mode: BuildMode):
     async def reader(label: str, stream: asyncio.StreamReader) -> None:
         async for line in stream:
             line = line.decode("utf-8", errors="replace")
-            print(f"[{label}] {line}", end='')
+            print(f"[{label}] {line}", end="")
             output_lines.append(f"[{label}] {line}")
             if (not found_build.is_set()) and (build_phrase in line):
                 found_build.set()
@@ -311,6 +318,7 @@ async def test_end_to_end(case: E2ECase, build_mode: BuildMode):
         code = proc.returncode
         pytest.fail(
             "End-to-end run did not reach expected state.\n"
+            f"command={shlex.join(cmd)}\n"
             f"returncode={code}\n"
             f"Saw build={found_build.is_set()} serve={found_serve.is_set()}\n\n"
             f"--- Captured output start ---\n{full_output}\n--- Captured output end ---"
